pub fn run_timeline(config: TimelineConfig) -> Result<i32>Expand description
Run the timeline command, returning the desired exit code.
pub fn run_timeline(config: TimelineConfig) -> Result<i32>Run the timeline command, returning the desired exit code.