Vulnerability grouping by root cause component.
This module provides functionality to group vulnerabilities by the component that introduces them, reducing noise and showing the true scope of security issues.
Structs
- Vulnerability
Group - A group of vulnerabilities sharing the same root cause component
- Vulnerability
Grouped View - Grouped view of vulnerability changes
Enums
- Vuln
Group Status - Status of a vulnerability group
Functions
- group_
vulnerabilities - Group vulnerabilities by component