pub struct IncrementalDiffEngine { /* private fields */ }Expand description
A diff engine wrapper that supports incremental computation and caching.
Wraps the standard DiffEngine and adds:
- Result caching for repeated comparisons
- Section-level change detection
- Incremental recomputation for partial changes
Implementations
Sourceimpl IncrementalDiffEngine
impl IncrementalDiffEngine
Sourcepub fn new(engine: DiffEngine) -> Self
pub fn new(engine: DiffEngine) -> Self
Create a new incremental diff engine.
Sourcepub fn with_cache_config(engine: DiffEngine, config: DiffCacheConfig) -> Self
pub fn with_cache_config(engine: DiffEngine, config: DiffCacheConfig) -> Self
Create with custom cache configuration.
Sourcepub fn diff(
&self,
old: &NormalizedSbom,
new: &NormalizedSbom,
) -> IncrementalDiffResult
pub fn diff( &self, old: &NormalizedSbom, new: &NormalizedSbom, ) -> IncrementalDiffResult
Perform a diff, using cache when possible.
Returns the diff result and metadata about cache usage.
Sourcepub const fn engine(&self) -> &DiffEngine
pub const fn engine(&self) -> &DiffEngine
Get the underlying engine.
Sourcepub fn cache_stats(&self) -> CacheStats
pub fn cache_stats(&self) -> CacheStats
Get cache statistics.
Sourcepub fn clear_cache(&self)
pub fn clear_cache(&self)
Clear the cache.