pub struct AdaptiveThreshold { /* private fields */ }Expand description
Adaptive threshold adjuster.
Implementations
Sourceimpl AdaptiveThreshold
impl AdaptiveThreshold
Sourcepub const fn new(config: AdaptiveThresholdConfig) -> Self
pub const fn new(config: AdaptiveThresholdConfig) -> Self
Create a new adaptive threshold adjuster with the given config.
Sourcepub fn compute_threshold(
&self,
old_sbom: &NormalizedSbom,
new_sbom: &NormalizedSbom,
matcher: &FuzzyMatcher,
) -> AdaptiveThresholdResult
pub fn compute_threshold( &self, old_sbom: &NormalizedSbom, new_sbom: &NormalizedSbom, matcher: &FuzzyMatcher, ) -> AdaptiveThresholdResult
Compute the optimal threshold for matching between two SBOMs.