pub struct BatchCandidateGenerator { /* private fields */ }Expand description
Batch candidate generator that combines multiple indexing strategies.
For best recall, combines:
ComponentIndex(ecosystem, prefix, trigram-based)- LSH index (for large SBOMs, catches approximate matches)
- Cross-ecosystem mappings (optional)
The candidates from each source are deduplicated and merged.
Implementations
Sourceimpl BatchCandidateGenerator
impl BatchCandidateGenerator
Sourcepub fn build(sbom: &NormalizedSbom, config: BatchCandidateConfig) -> Self
pub fn build(sbom: &NormalizedSbom, config: BatchCandidateConfig) -> Self
Create a new batch candidate generator from an SBOM.
Sourcepub fn find_candidates(
&self,
source_id: &CanonicalId,
source_component: &Component,
) -> BatchCandidateResult
pub fn find_candidates( &self, source_id: &CanonicalId, source_component: &Component, ) -> BatchCandidateResult
Generate candidates for a single component.
Sourcepub fn find_candidates_batch(
&self,
sources: &[(&CanonicalId, &Component)],
) -> Vec<BatchCandidateResult>
pub fn find_candidates_batch( &self, sources: &[(&CanonicalId, &Component)], ) -> Vec<BatchCandidateResult>
Generate candidates for multiple components in parallel.
Sourcepub fn all_candidates(
&self,
source_id: &CanonicalId,
source_component: &Component,
) -> Vec<CanonicalId>
pub fn all_candidates( &self, source_id: &CanonicalId, source_component: &Component, ) -> Vec<CanonicalId>
Get all unique candidates (deduplicated across all strategies).
Sourcepub const fn component_index(&self) -> &ComponentIndex
pub const fn component_index(&self) -> &ComponentIndex
Get the underlying component index.
Sourcepub const fn has_cross_ecosystem(&self) -> bool
pub const fn has_cross_ecosystem(&self) -> bool
Check if cross-ecosystem matching is enabled.
Sourcepub fn stats(&self) -> BatchCandidateStats
pub fn stats(&self) -> BatchCandidateStats
Get statistics about the generator.