pub struct AliasTable { /* private fields */ }Expand description
Alias table for mapping package names across different conventions.
Implementations
Sourceimpl AliasTable
impl AliasTable
Sourcepub fn with_builtins() -> Self
pub fn with_builtins() -> Self
Create an alias table with built-in common aliases
Sourcepub fn add_aliases(&mut self, canonical: &str, aliases: &[&str])
pub fn add_aliases(&mut self, canonical: &str, aliases: &[&str])
Add aliases for a canonical package
Sourcepub fn get_canonical(&self, alias: &str) -> Option<String>
pub fn get_canonical(&self, alias: &str) -> Option<String>
Get the canonical name for an alias
Sourcepub fn is_alias(&self, canonical: &str, name: &str) -> bool
pub fn is_alias(&self, canonical: &str, name: &str) -> bool
Check if a name is an alias of a canonical name