#[non_exhaustive]pub struct CertificateProperties {
pub subject_name: Option<String>,
pub issuer_name: Option<String>,
pub not_valid_before: Option<DateTime<Utc>>,
pub not_valid_after: Option<DateTime<Utc>>,
pub signature_algorithm_ref: Option<String>,
pub subject_public_key_ref: Option<String>,
pub certificate_format: Option<String>,
pub certificate_extension: Option<String>,
}Expand description
Properties of a digital certificate asset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.subject_name: Option<String>Certificate subject distinguished name.
issuer_name: Option<String>Certificate issuer distinguished name.
not_valid_before: Option<DateTime<Utc>>Start of validity period.
not_valid_after: Option<DateTime<Utc>>End of validity period.
signature_algorithm_ref: Option<String>Bom-ref of the signature algorithm component.
subject_public_key_ref: Option<String>Bom-ref of the subject public key component.
certificate_format: Option<String>Certificate format (e.g., “X.509”).
certificate_extension: Option<String>Certificate file extension (e.g., “pem”, “crt”, “der”).
Implementations
Sourceimpl CertificateProperties
impl CertificateProperties
pub fn new() -> Self
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Returns true if the certificate has expired.
Sourcepub fn is_expiring_soon(&self, days: u32) -> bool
pub fn is_expiring_soon(&self, days: u32) -> bool
Returns true if the certificate expires within the given number of days.
Sourcepub fn validity_days(&self) -> Option<i64>
pub fn validity_days(&self) -> Option<i64>
Returns remaining days until expiry, or None if no expiry date is set.
Returns negative values for already-expired certificates.
pub fn with_subject_name(self, name: String) -> Self
pub fn with_issuer_name(self, name: String) -> Self
pub fn with_not_valid_before(self, dt: DateTime<Utc>) -> Self
pub fn with_not_valid_after(self, dt: DateTime<Utc>) -> Self
pub fn with_signature_algorithm_ref(self, r: String) -> Self
pub fn with_subject_public_key_ref(self, r: String) -> Self
pub fn with_certificate_format(self, fmt: String) -> Self
pub fn with_certificate_extension(self, ext: String) -> Self