CLI command handlers.
This module provides testable command handlers that are invoked by main.rs. Each handler implements the business logic for a specific CLI subcommand.
Re-exports
pub use crate::config::DiffConfig;pub use crate::config::ViewConfig;
Structs
- Query
Filter - Filter criteria for querying components across SBOMs.
Functions
- run_
diff - Run the diff command, returning the desired exit code.
- run_
diff_ multi - Run the diff-multi command (1:N comparison)
- run_
matrix - Run the matrix command (N×N comparison)
- run_
quality - Run the quality command, returning the desired exit code.
- run_
query - Run the query command.
- run_
timeline - Run the timeline command
- run_
validate - Run the validate command
- run_
view - Run the view command
- run_
watch - Run the watch command with the given configuration.