Module cli

Module cli 

CLI command handlers.

This module provides testable command handlers that are invoked by main.rs. Each handler implements the business logic for a specific CLI subcommand.

Re-exports

pub use crate::config::DiffConfig;
pub use crate::config::ViewConfig;

Structs

QueryFilter
Filter criteria for querying components across SBOMs.

Enums

VerifyAction
Verify action to perform
VexAction
VEX action to perform.

Functions

run_diff
Run the diff command, returning the desired exit code.
run_diff_multi
Run the diff-multi command (1:N comparison)
run_enrich
Run the enrich command.
run_license_check
Run the license-check command.
run_matrix
Run the matrix command (N×N comparison)
run_merge
Run the merge command.
run_quality
Run the quality command, returning the desired exit code.
run_query
Run the query command.
run_tailor
Run the tailor command.
run_timeline
Run the timeline command
run_validate
Run the validate command
run_verify
Run the verify command.
run_vex
Run the vex subcommand.
run_view
Run the view command
run_watch
Run the watch command with the given configuration.