Module cli

Module cli 

CLI command handlers.

This module provides testable command handlers that are invoked by main.rs. Each handler implements the business logic for a specific CLI subcommand.

Re-exports

pub use crate::config::DiffConfig;
pub use crate::config::ViewConfig;

Functions

run_diff
Run the diff command, returning the desired exit code.
run_diff_multi
Run the diff-multi command (1:N comparison)
run_matrix
Run the matrix command (N×N comparison)
run_quality
Run the quality command, returning the desired exit code.
run_timeline
Run the timeline command
run_validate
Run the validate command
run_view
Run the view command